﻿open Expecto

/// Whether to only run RethinkDB data tests
let rethinkOnly = (RethinkDbDataTests.env "RETHINK_ONLY" "0") = "1"

/// Whether to only run SQLite data tests
let sqliteOnly = (RethinkDbDataTests.env "SQLITE_ONLY" "0") = "1"

/// Whether to only run PostgreSQL data tests
let postgresOnly = (RethinkDbDataTests.env "PG_ONLY" "0") = "1"

/// Whether any of the data tests are being isolated
let allDatabases = not (rethinkOnly || sqliteOnly || postgresOnly)

let allTests = testList "MyWebLog" [
    // Skip unit tests if running an isolated database test
    if allDatabases then
        testList "Domain" [ SupportTypesTests.all; DataTypesTests.all; ViewModelsTests.all ]
        testList "Data (Unit)" [ ConvertersTests.all; UtilsTests.all ]
    // Whether to skip integration tests
    if RethinkDbDataTests.env "UNIT_ONLY" "0" <> "1" then
        testList "Data (Integration)" [
            if allDatabases || rethinkOnly  then RethinkDbDataTests.all
            if allDatabases || sqliteOnly   then SQLiteDataTests.all
            if allDatabases || postgresOnly then PostgresDataTests.all
        ]
]

[<EntryPoint>]
let main args = runTestsWithCLIArgs [] args allTests
